@@ -15,14 +15,18 @@
 """
 Cloudant / CouchDB Python client library API package
 """
-__version__ = '2.14.0'
+__version__ = '2.15.0'
 
 # pylint: disable=wrong-import-position
 import contextlib
+import warnings
 # pylint: disable=wrong-import-position
 from .client import Cloudant, CouchDB
 from ._common_util import CloudFoundryService
 
+warnings.warn('The module cloudant is now deprecated. The replacement is ibmcloudant.',
+              DeprecationWarning)
+
 @contextlib.contextmanager
 def cloudant(user, passwd, **kwargs):
     """
