@@ -706,6 +706,24 @@ class CouchDatabase(dict):
             raise KeyError(key)
         return doc
 
+    def get(self, key, remote=False):
+        """
+        Overrides dict's get method. This gets an item from the database or cache
+        like __getitem__, but instead of throwing an exception if the item is not
+        found, it simply returns None.
+
+        :param bool remote: Dictates whether a remote request is made to
+            retrieve the doc, if it is not present in the local cache.
+            Defaults to False.
+        """
+        if remote:
+            try:
+                return self.__getitem__(key)
+            except KeyError:
+                return None
+        else:
+            return super(CouchDatabase, self).get(key)
+
     def __contains__(self, key):
         """
         Overrides dictionary __contains__ behavior to check if a document
@@ -1242,8 +1260,7 @@ class CouchDatabase(dict):
             wrapped in a QueryResult or if the response JSON is returned.
             Defaults to False.
         :param str bookmark: A string that enables you to specify which page of
-            results you require. Only valid for queries using indexes of type
-            *text*.
+            results you require.
         :param int limit: Maximum number of results returned.  Only valid if
             used with ``raw_result=True``.
         :param int page_size: Sets the page size for result iteration.  Default
