@@ -397,9 +397,10 @@ class Result(object):
 
                 # if we are in a view, keys could be duplicate so we
                 # need to start from the right docid
-                if last['id']:
+                last_doc_id = last.get('id')
+                if last_doc_id is not None:
                     response = self._call(startkey=last['key'],
-                                          startkey_docid=last['id'])
+                                          startkey_docid=last_doc_id)
                 # reduce result keys are unique by definition
                 else:
                     response = self._call(startkey=last['key'])
@@ -488,8 +489,7 @@ class QueryResult(Result):
     :param query: A reference to the query callable that returns
         the JSON content result to be wrapped.
     :param str bookmark: A string that enables you to specify which page of
-        results you require. Only valid for queries using indexes of type
-        *text*.
+        results you require.
     :param list fields: A list of fields to be returned by the query.
     :param int page_size: Sets the page size for result iteration.  Default
         is 100.
